@@ -91,7 +91,6 @@ public:
 
     // Pointer to the apt cache object
     Cache *cache;
-    pkgPolicy *policy;
     pkgRecords *records;
 
     // Undo/redo stuff
@@ -253,7 +252,7 @@ void Backend::reloadCache()
             pkgCache::VerFileIterator VF = Ver.FileList();
             QLatin1String origin(QLatin1String(VF.File().Origin()));
             d->originMap[origin] = VF.File().Label();
-            d->siteMap[VF.File().Site()] = origin;
+            d->siteMap[origin] = VF.File().Site();
         }
     }
 
@@ -338,7 +337,7 @@ Package *Backend::package(pkgCache::PkgIterator &iter) const
     Q_D(const Backend);
 
     int index = d->packagesIndex.at(iter->ID);
-    if (index != -1) {
+    if (index != -1 && index < d->packages.size()) {
         return d->packages.at(index);
     }
     return 0;
@@ -1530,10 +1529,10 @@ void Backend::serviceOwnerChanged(const QString &name, const QString &oldOwner,
     }
 }
 
-QString Backend::originForSite(const QString& host) const
+QStringList Backend::originsForHost(const QString& host) const
 {
     Q_D(const Backend);
-    return d->siteMap[host];
+    return d->siteMap.keys(host);
 }
 
 }
