@@ -497,6 +497,24 @@ void QAptWorker::commitChanges(QMap<QString, QVariant> instructionsList)
         return;
     }
 
+    bool failed = false;
+    for (pkgAcquire::ItemIterator i = fetcher.ItemsBegin(); i != fetcher.ItemsEnd(); ++i) {
+        if((*i)->Status == pkgAcquire::Item::StatDone && (*i)->Complete)
+            continue;
+        if((*i)->Status == pkgAcquire::Item::StatIdle)
+            continue;
+
+        failed = true;
+        break;
+    }
+
+    if (failed && !packageManager->FixMissing()) {
+        emit errorOccurred(QApt::FetchError, QVariantMap());
+        emit workerFinished(false);
+        m_timeout->start();
+        return;
+    }
+
     emit workerEvent(QApt::PackageDownloadFinished);
 
     emit workerEvent(QApt::CommitChangesStarted);
@@ -614,9 +632,9 @@ void QAptWorker::installDebFile(const QString &fileName)
     archList.append(QLatin1String("all"));
     std::vector<std::string> archs = APT::Configuration::getArchitectures(false);
 
-    for (std::string &arch : archs)
+    for (int i = 0; i < archs.size(); i++)
     {
-         archList.append(QString::fromStdString(arch));
+         archList.append(QString::fromStdString(archs.at(i)));
     }
 
     if (!archList.contains(debArch)) {
